import sys

MIN_POINTS = 1
MAX_POINTS = 100000
MIN_XY = -10**9
MAX_XY = 10**9

instr = sys.stdin

class point:
    def __init__(self, x, y):
        self.x = x
        self.y = y

    def __eq__(self, other):
        return (isinstance(other, self.__class__) and self.x == other.x and self.y == other.y)

    def __ne__(self, other):
        return not self.__eq__(other)

    def __str__(self):
        return "(" + str(self.x) + ", " + str(self.y) + ")"

    def __repr__(self):
        return self.__str__()

class line:
    def __init__(self, p1, p2):
        self.p1 = p1
        self.p2 = p2

    def __str__(self):
        return "[" + str(self.p1) + " -> " + str(self.p2) + "]"

    def __repr__(self):
        return self.__str__()

# http://www.helpwithfractions.com/math-homework-helper/equivalent-fractions/
# What this Rule says is that two fractions are equivalent (equal) only if the product of the numerator (a)
# of the first fraction and the denominator (d) of the other fraction
# is equal to the product of the denominator (b) of the first fraction and the numerator (c) of the other fraction.
def equal(a1, b1, a2, b2):
    return a1 * b2 == a2 * b1

# https://www.algebra.com/algebra/homework/Functions/Functions.faq.question.123365.html
# Collinear points would be on a line with the same slope. 
# You can calculate the slope of a line between each data pair.
# If the slopes all match, the points are all on a line (collinear)
def collinear(x1, y1, x2, y2, x3, y3):
    dx12 = x2 - x1
    dy12 = y2 - y1
    dx23 = x3 - x2
    dy23 = y3 - y2

    return equal(dx12, dy12, dx23, dy23)

def debug_find_line(points):
    for pj in points:
        for pk in points:
            if pj == pk: continue
            for p in points:
                if pj == p: continue
                if pk == p: continue
                if collinear(pj.x, pj.y, pk.x, pk.y, p.x, p.y): 
                    return line(pj, p)
    return None


def find_line(points, p):
    for pj in points:
        if pj == p: continue
        for pk in points:
            if pj == pk: continue
            if pk == p: continue
            if collinear(pj.x, pj.y, pk.x, pk.y, p.x, p.y): 
                return line(pj, p)
    return None

def read_points():
    input = instr.readline()
    inputs = input.split(' ')
    x = int(inputs[0])
    y = int(inputs[1])
    return x, y

def magic():
    # Read number of points
    input = instr.readline()
    n = int(input)
    
    assert n >= MIN_POINTS
    assert n <= MAX_POINTS

    # Take first two points
    points = []
    i_x, i_y = read_points()
    points.append(point(i_x, i_y))
    i_x, i_y = read_points()
    points.append(point(i_x, i_y))

    first_line = line(point(0, 0), point(0, 0))
    first_line_found = False
    second_line = line(point(0, 0), point(0, 0))
    second_line_found = False
    points_not_on_first_line = 0

    result = True
    result_determined = False
    for i in range(2, n):
        x, y = read_points()
        assert x >= MIN_XY
        assert x <= MAX_XY
        assert y >= MIN_XY
        assert y <= MAX_XY

        p = point(x, y)
        points.append(p)

        if result_determined: continue

        # Determine whether the next point is collinear with the first points
        if not first_line_found:
            # Try to find three points that are on a single line
            first_line = find_line(points, p)
            if first_line:
                first_line_found = True
                # Remove the points on the line, as we don't need to check them anymore
                points.remove(first_line.p1)
                points.remove(first_line.p2)
            if not first_line_found and len(points) == 5:
                result = False
                result_determined = True # Continue reading all lines

        # If we already found a line, determine whether the next point is collinear with this line
        elif not collinear(first_line.p1.x, first_line.p1.y, first_line.p2.x, first_line.p2.y, p.x, p.y):
            # The point is not on the same line. So we have to find another line
            points_not_on_first_line += 1
            # Try to find three points that are on a single line
            if not second_line_found:
                second_line = find_line(points, p)
                if second_line is not None:
                    # Second line was found!
                    second_line_found = True
                    # Remove the points on the line, as we don't need to check them anymore
                    points.remove(second_line.p1)
                    points.remove(second_line.p2)
            
            # If a second line was already found and the new point is not one the first or second line, then we have to have a third line, which is too much 
            if second_line_found:
                if not collinear(second_line.p1.x, second_line.p1.y, second_line.p2.x, second_line.p2.y, p.x, p.y):
                    # We have two lines, but that's still not enough... So we lose!
                    result = False
                    result_determined = True # Continue reading all lines
                else: # The found point was collinear with the second line, so we remove it from the list of points as we don't have to check it anymore
                    if p in points: points.remove(p)
        else: # The found point was collinear with the first line, so we remove it from the list of points as we don't have to check it anymore
            points.remove(p)
    
    # Return the answer
    if n <= 4: return True # 4 points can always be connected by two lines
    if result_determined: return result
    if points_not_on_first_line > 2 and not second_line_found: return False
    return True

def solve():
    if magic():
        print("success")
    else: print("failure")

def main():
    solve()

if __name__ == "__main__":
    main()
