import sys
from collections import deque

MIN_PLAYERS = 2
MAX_PLAYERS = 100000 // 2
MIN_EDGES = 1
MIN_VERTEX_ID = 0
MAX_EDGES = 500000 // 2
MAX_VERTEX_ID = MAX_PLAYERS - 1

instr = sys.stdin

class graph:
    def __init__(self):
        self.edges = []
        self.vertices = []
    
    def __init__(self, vertices, edges):
        self.vertices = vertices
        self.edges = edges
    
    def __str__(self):
        result = ""
        result += "Vertices:\n"
        for v in self.vertices:
            result += "\t" + str(v) + "\n"
        result += "Edges:\n"
        for e in self.edges:
            result += "\t" + str(e) + "\n"
        return result

    def __repr__(self):
        return self.__str__()

class vertex:
    def __init__(self, id):
        self.id = id
        self.edges = []
        self.parent = None
        self.parent2 = None
        self.parent_edge = None

    def __str__(self):
        return str(self.id)

    def __repr__(self):
        return self.__str__()

    def __eq__(self, other):
        return (isinstance(other, self.__class__) and self.id == other.id)

    def __ne__(self, other):
        return not self.__eq__(other)
        
    def __hash__(self):
        return self.id

class edge:
    def __init__(self, v1, v2, result):
        self.v1 = v1
        self.v2 = v2
        self.result = result

    @property
    def directed(self):
        return self.result == '>'
        
    def connected(self, vertex):
        return self.v1.id == vertex.id or self.v2.id == vertex.id
        
    def __str__(self):
        return "[{} {} {}]".format(self.v1, self.result, self.v2) 

    def __repr__(self):
        return self.__str__()
        
    def __eq__(self, other):
        return (isinstance(other, self.__class__) and self.__dict__ == other.__dict__)

    def __ne__(self, other):
        return not self.__eq__(other)
        
    def __hash__(self):
        if self.v1.id < self.v2.id:
            return "{}_{}".format(self.v1.id, self.v2.id).__hash__()
        else: return "{}_{}".format(self.v2.id, self.v1.id).__hash__()

def solve():
    while True:
        g = read_graph()
        if g is None: return
        
        input_check_duplicate_edges(g)
        v, e, ce = spanning_tree(g)
        cycles = detect_cycles(v, e, ce)
        result = "inconsistent" if cycles else "consistent"
        print(result, flush=True)

def detect_cycles(verticeset, edgeset_in_tree, cycle_edges):
    # For each directed edge not in tree: add it to the tree and see whether a cycle is created
    vertices = list(verticeset)
    edges = list(cycle_edges)

    for cycle_edge in edges:
        if not cycle_edge.directed: continue

        visited = set([])
        visited_edges = set([])
        stack = deque()
        in_stack = set([])

        stack.append(cycle_edge.v2)
        in_stack.add(cycle_edge.v2)
        visited.add(cycle_edge.v2)

        cycle_edge.v1.edges.append(cycle_edge)
        cycle_edge.v2.edges.append(cycle_edge)
        
        while len(stack) > 0:
            v_current = stack.pop()
            in_stack.remove(v_current)
            for e in v_current.edges:
                if e in visited_edges: continue
                to_add = None
                if not e.directed:
                    if v_current.id != e.v1.id:
                        to_add = e.v1
                    else: 
                        to_add = e.v2
                    to_add.parent_edge = e
                elif v_current.id != e.v2.id:
                    to_add = e.v2
                    to_add.parent_edge = e
                else: continue
                visited_edges.add(e)

                if to_add == cycle_edge.v1:
                    return True
                
                if to_add not in visited and to_add not in stack:
                    stack.append(to_add)
                    in_stack.add(to_add)
                visited.add(v_current)
        cycle_edge.v1.edges.remove(cycle_edge)
        cycle_edge.v2.edges.remove(cycle_edge)

    return False

def spanning_tree(gr):
    vertices_in_tree = set([])
    edges_in_tree = set([])
    vertices_in_graph = set(gr.vertices)

    while len(vertices_in_graph - vertices_in_tree) > 0:
        queue = deque()
        directed_queue = deque()
        for v in vertices_in_graph:
            if v not in vertices_in_tree:
                queue.append(v)
                break

        while len(queue) > 0 or len(directed_queue) > 0:
            if len(queue) > 0:
                v = queue.popleft()
                directed_queue.append(v)

                for e in v.edges:
                    if not e.directed and e.v1 not in vertices_in_tree:
                        edges_in_tree.add(e)
                        queue.append(e.v1)
                        vertices_in_tree.add(e.v1)
                    if not e.directed and e.v2 not in vertices_in_tree:
                        edges_in_tree.add(e)
                        queue.append(e.v2)
                        vertices_in_tree.add(e.v2)
            
            if len(queue) == 0:
                if len(directed_queue) > 0:
                    v = directed_queue.popleft()
                    for e in v.edges:
                        if e.v1 not in vertices_in_tree:
                            if e.directed:
                                edges_in_tree.add(e)
                                queue.append(e.v1)
                                vertices_in_tree.add(e.v1)
                        if e.v2 not in vertices_in_tree:
                            if e.directed:
                                edges_in_tree.add(e)
                                queue.append(e.v2)
                                vertices_in_tree.add(e.v2)

    cycle_edges = []
    for e in gr.edges:
        if e not in edges_in_tree:
            cycle_edges.append(e)
            e.v1.edges.remove(e)
            e.v2.edges.remove(e)

    return vertices_in_tree, edges_in_tree, cycle_edges

def read_graph():
    input = instr.readline()
    if not input: return None
    inputs = input.split(' ')
    
    try: n = int(inputs[0])
    except ValueError:
        raise Exception("Expected integer while reading number of players")
        
    try: m = int(inputs[1])
    except ValueError:
        raise Exception("Expected integer while reading number of matches")

    if n < MIN_PLAYERS or n > MAX_PLAYERS:
        raise Exception("Input value [n] is out of range: {}".format(n))

    if m < MIN_EDGES or m > MAX_EDGES:
        raise Exception("Input value [m] is out of range: {}".format(n))
    
    edges = []
    vertices = []
    verticedict = dict()
    edgeset = set([])
    verticeset = set([])
    for i in range(1, m + 1):
        input = instr.readline()
        inputs = input.split(' ')
        n_s1 = int(inputs[0])
        n_r = inputs[1]
        n_s2 = int(inputs[2])
        
        assert n_s1 >= MIN_VERTEX_ID and n_s1 <= MAX_VERTEX_ID
        assert n_s2 >= MIN_VERTEX_ID and n_s2 <= MAX_VERTEX_ID
        assert n_s1 != n_s2
        assert n_s1 < n
        assert n_s2 < n
        assert n_r == '=' or n_r == '>'

        v1 = vertex(n_s1)
        v2 = vertex(n_s2)
        if v1 not in verticeset:
            vertices.append(v1)
            verticeset.add(v1)
            verticedict[v1.id] = v1
        else: v1 = verticedict[v1.id]
        if v2 not in verticeset:
            vertices.append(v2)
            verticeset.add(v2)
            verticedict[v2.id] = v2
        else: v2 = verticedict[v2.id]
      
        e = edge(v1, v2, n_r)
        edges.append(e)
        edgeset.add(e)
        v1.edges.append(e)
        v2.edges.append(e)
        
    return graph(vertices, edges)

def input_check_duplicate_edges(gr):
    parsed_edges = set()
    for e in gr.edges:
        assert e.__hash__() not in parsed_edges
        parsed_edges.add(e.__hash__())

def main():
    solve()

if __name__ == "__main__":
    main()
